# books-dl

Консольная утилита для загрузки книжек с одного замечательного сайта.

## Установка

``` sh
pip install books-dl
```

## Использование

```
usage: books-dl [-h] [-d Директория] [-nc] Запрос
Консольная утилита для загрузки книжек с одного замечательного сайта

positional arguments:
  Запрос                Запрос для поиска

optional arguments:
  -h, --help            show this help message and exit
  -d Директория, --directory Директория
                        Директория для загрузки книг. Если не указана, то
                        используется текущая
  -nc, --no-cover       Не загружать обложку
```

Примечание: имя автора всегда следует вводить на русском языке, даже если искомая книжка не на нём.

